
#line 3 "scannerlexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#ifndef _POSIX_C_SOURCE
#define _POSIX_C_SOURCE 1 /* for fileno() */
#ifndef _POSIX_SOURCE
#define _POSIX_SOURCE 1
#endif
#endif
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 145
#define YY_END_OF_BUFFER 146
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[925] =
    {   0,
      146,  144,  145,    3,  144,  145,    1,  145,   35,  144,
      145,  144,  145,   10,  144,  145,   30,  144,  145,   32,
      144,  145,  144,  145,   19,  144,  145,   20,  144,  145,
       28,  144,  145,   26,  144,  145,   59,  144,  145,   27,
      144,  145,   25,  144,  145,   29,  144,  145,  137,  144,
      145,  137,  144,  145,   22,  144,  145,   21,  144,  145,
       37,  144,  145,   36,  144,  145,   38,  144,  145,   24,
      144,  145,   93,  134,  144,  145,   93,  134,  144,  145,
       15,  144,  145,  144,  145,   17,  144,  145,   31,  144,
      145,   93,  134,  144,  145,   93,  134,  144,  145,   93,

      134,  144,  145,   93,  134,  144,  145,   93,  134,  144,
      145,   93,  134,  144,  145,   93,  134,  144,  145,   93,
      134,  144,  145,   93,  134,  144,  145,   93,  134,  144,
      145,   93,  134,  144,  145,   93,  134,  144,  145,   93,
      134,  144,  145,   93,  134,  144,  145,   93,  134,  144,
      145,   93,  134,  144,  145,   11,  144,  145,   33,  144,
      145,   13,  144,  145,   34,  144,  145,    3,    1,   52,
      142,   43,   14,   55,   45,  140,   41,   57,   39,   58,
       40,   60,  138,    4,    5,   42,  138,  136,  137,  137,
      137,  137,   18,   12,   16,   47,   53,   51,   54,   48,

       93,  134,    2,   44,   93,  134,   93,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   93,  103,
      134,   93,  134,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   93,  111,  134,   93,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   46,   56,
       23,  138,    5,  136,  137,  136,  137,  139,  137,  137,
      137,  135,   49,   50,  143,  141,   93,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   93,  134,

       93,  134,   93,  134,   93,  134,   93,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   93,   94,
      134,   93,  134,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   93,  134,   93,  109,  134,   93,  134,
       93,  134,   93,  113,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   93,  134,   93,  134,  138,  136,  137,
      136,  137,  136,  137,  139,  137,  135,  135,   93,  134,

       93,  134,   93,  134,   93,  134,   93,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   93,   95,
      134,   93,   96,  134,   93,  134,   93,   98,  134,   93,
       99,  134,   93,  134,   93,  134,   93,  134,   93,  134,
       93,  105,  134,   93,  106,  134,   93,  134,   93,  134,
       93,  110,  134,   93,  134,   93,  118,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   93,  134,

       93,  134,   93,  131,  134,   93,  134,   93,  134,    8,
      136,  137,  135,  135,  135,   84,   93,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   64,   93,  134,   93,
      134,   93,  134,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   93,  134,   93,  134,   90,   93,  134,
       93,   97,  134,   93,  100,  134,   93,  134,   93,  134,
       93,  134,   93,  134,   93,  108,  134,   93,  134,   93,
      134,   93,  134,   93,  134,   93,  122,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   93,  134,

       93,  129,  134,   93,  134,   93,  134,   93,  133,  134,
      135,   93,  134,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   93,  134,   93,  134,   93,  104,  134,
       93,  107,  134,   93,  112,  134,   93,  134,   93,  134,
       93,  121,  134,   93,  123,  134,   93,  124,  134,   93,
      125,  134,   93,  126,  134,   93,  127,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   93,  134,

       93,  134,   93,  134,   65,   93,  134,   93,  134,   86,
       93,  134,   68,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   91,   93,  134,   93,  134,   93,  134,
       93,  134,   93,  134,   93,  134,   93,  134,   93,  134,
       93,  134,   93,  102,  134,   93,  134,   93,  134,   93,
      128,  134,   93,  134,   93,  134,   93,  134,   73,   93,
      134,   93,  134,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   71,   93,  134,   93,  117,  134,   93,
      134,   93,  134,   77,   93,  134,   93,  134,   81,   93,
      134,   93,  134,   93,  134,   93,  101,  134,   93,  119,

      134,   93,  120,  134,   93,  130,  134,   93,  132,  134,
        7,    9,   92,   93,  134,   76,   93,  134,   93,  134,
       74,   93,  134,   93,  134,   93,  134,   93,  134,   93,
      134,   93,  134,   72,   93,  134,   93,  134,   93,  134,
       89,   93,  134,   93,  116,  134,   93,  134,    6,    7,
       93,  134,   93,  134,   93,  134,   93,  134,   70,   93,
      134,   93,  115,  134,   79,   93,  134,   78,   93,  134,
       93,  134,   82,   93,  134,   93,  134,   67,   93,  134,
       93,  134,   93,  134,   93,  114,  134,   93,  134,   93,
      134,   93,  134,   93,  134,   80,   93,  134,   83,   93,

      134,   93,  134,   66,   93,  134,   88,   69,   93,  134,
       93,  134,   61,   93,  134,   93,  134,   62,   75,   93,
      134,   63,   87,   85
    } ;

static const flex_int16_t yy_accept[539] =
    {   0,
        1,    1,    1,    2,    4,    7,    9,   12,   14,   17,
       20,   23,   25,   28,   31,   34,   37,   40,   43,   46,
       49,   52,   55,   58,   61,   64,   67,   70,   73,   77,
       81,   84,   86,   89,   92,   96,  100,  104,  108,  112,
      116,  120,  124,  128,  132,  136,  140,  144,  148,  152,
      156,  159,  162,  165,  168,  169,  170,  171,  171,  172,
      172,  172,  172,  172,  173,  174,  175,  176,  176,  177,
      177,  178,  179,  180,  181,  182,  183,  183,  184,  185,
      186,  187,  188,  190,  191,  191,  192,  193,  193,  194,
      195,  196,  197,  198,  199,  200,  201,  203,  203,  203,

      204,  205,  207,  209,  211,  213,  215,  217,  219,  221,
      223,  225,  227,  229,  232,  234,  236,  238,  240,  242,
      244,  247,  249,  251,  253,  255,  257,  259,  261,  263,
      265,  267,  269,  270,  271,  271,  271,  271,  272,  272,
      273,  274,  276,  278,  278,  279,  280,  281,  282,  283,
      284,  285,  285,  286,  286,  286,  287,  287,  289,  291,
      293,  295,  297,  299,  301,  303,  305,  307,  309,  311,
      313,  315,  317,  319,  322,  324,  326,  328,  330,  332,
      334,  336,  338,  340,  342,  344,  346,  349,  351,  353,
      356,  358,  360,  362,  364,  366,  368,  370,  372,  374,

      376,  378,  380,  382,  384,  386,  388,  388,  388,  388,
      388,  389,  391,  393,  395,  396,  397,  398,  399,  401,
      403,  405,  407,  409,  411,  413,  415,  417,  419,  421,
      423,  425,  427,  429,  431,  433,  435,  437,  439,  442,
      445,  447,  450,  453,  455,  457,  459,  461,  464,  467,
      469,  471,  474,  476,  479,  481,  483,  485,  487,  489,
      491,  493,  495,  497,  499,  501,  503,  506,  508,  510,
      510,  511,  511,  511,  513,  514,  515,  516,  519,  521,
      523,  525,  527,  530,  532,  534,  536,  538,  540,  542,
      544,  546,  548,  550,  552,  554,  556,  558,  561,  564,

      567,  569,  571,  573,  575,  578,  580,  582,  584,  586,
      589,  591,  593,  595,  597,  599,  601,  604,  606,  608,
      611,  611,  611,  612,  614,  616,  618,  620,  622,  622,
      624,  626,  628,  630,  632,  634,  636,  638,  640,  642,
      644,  646,  648,  650,  652,  654,  656,  658,  661,  664,
      667,  669,  671,  674,  677,  680,  683,  686,  689,  691,
      693,  695,  695,  695,  697,  699,  701,  703,  705,  705,
      708,  710,  713,  716,  718,  720,  722,  724,  727,  729,
      731,  733,  735,  737,  739,  741,  743,  746,  748,  750,
      753,  755,  757,  757,  757,  759,  762,  764,  766,  768,

      768,  768,  770,  772,  774,  777,  780,  782,  784,  787,
      789,  792,  794,  796,  799,  802,  805,  805,  808,  811,
      812,  812,  813,  816,  819,  821,  824,  824,  824,  824,
      826,  828,  830,  832,  834,  837,  839,  841,  844,  847,
      849,  849,  850,  851,  853,  853,  853,  853,  855,  857,
      859,  862,  865,  868,  871,  873,  876,  876,  878,  878,
      878,  878,  881,  881,  881,  883,  885,  888,  890,  890,
      892,  892,  892,  892,  894,  894,  894,  894,  896,  899,
      902,  902,  904,  904,  904,  904,  907,  908,  908,  911,
      911,  913,  914,  914,  914,  914,  914,  916,  916,  916,

      916,  916,  918,  918,  919,  919,  919,  922,  922,  922,
      922,  922,  922,  922,  922,  922,  922,  923,  923,  923,
      923,  923,  923,  923,  923,  923,  923,  924,  924,  924,
      924,  924,  924,  924,  924,  924,  925,  925
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       23,   24,   23,   25,   23,   26,   27,   28,   29,   30,
       31,   32,   33,    1,   34,   35,   34,   34,   36,   37,
       38,   38,   38,   38,   38,   39,   38,   40,   38,   38,
       38,   38,   38,   38,   41,   38,   38,   42,   38,   38,
       43,   44,   45,   46,   47,    1,   48,   49,   50,   51,

       52,   53,   54,   55,   56,   57,   58,   59,   60,   61,
       62,   63,   57,   64,   65,   66,   67,   68,   69,   70,
       71,   72,   73,   74,   75,   76,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[77] =
    {   0,
        1,    2,    3,    1,    2,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    1,    1,    1,    1,    5,
        5,    5,    5,    5,    5,    5,    5,    1,    1,    1,
        1,    1,    1,    6,    6,    6,    7,    8,    9,    8,
        8,    8,    1,    1,    1,    1,    8,   10,   10,   10,
       10,   10,   11,   12,   12,   12,   12,   12,   13,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   12,
       12,   12,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[555] =
    {   0,
        0,    0,  901,  902,   75,    0,  869,   71,   76,   51,
       74,   74,  902,  902,  868,   71,  902,   72,   70,   92,
      118,  171,  866,  902,   89,  866,   68,  902,    0,  101,
      902,  893,  902,  864,  111,   42,   52,  101,   69,   63,
       51,  832,   73,  831,  840,  106,  820,  829,  827,  833,
      902,   56,  902,  902,  148,    0,  902,  121,  902,  884,
      179,  834,  829,  902,  902,  902,  902,  136,  902,  881,
      902,  902,  902,  902,  902,  902,  865,  219,  902,    0,
      902,    0,  190,    0,  194,  194,  125,    0,  902,  902,
      902,  851,  902,  902,  902,  850,    0,  122,  215,  902,

      902,  818,  820,   70,  231,  818,  811,  814,  823,  809,
      825,  811,  818,  803,  804,  801,  801,  804,  801,  798,
        0,  108,  802,  117,  800,  101,  160,  805,  797,  113,
      120,  803,  902,  902,  242,  805,  796,  902,  286,  902,
        0,  235,  189,  294,  285,  146,  902,  195,  284,  902,
      902,  183,  902,  853,  226,  902,  852,  792,  791,  161,
      793,  185,  222,  799,  780,  788,  786,  795,  219,  775,
      789,  782,  818,    0,  780,  782,  792,  787,  774,  223,
      789,  787,  783,  774,  781,  784,    0,  769,  774,    0,
      775,  772,  761,  759,  761,  763,  771,  756,  754,  754,

      767,  756,  761,  765,  767,  755,  810,  756,  759,  306,
      297,  294,  902,  298,  902,  902,  300,  301,  751,  761,
      747,  755,  747,  745,  738,  751,  741,  751,  734,  227,
      738,  733,  743,  745,  732,  733,  734,  768,    0,    0,
      733,    0,    0,  724,  733,  721,  728,    0,    0,  722,
      719,    0,  723,    0,  718,  718,  717,  714,  727,  716,
      721,  726,  725,  723,  712,  718,    0,  705,  718,  766,
      902,  707,  762,  902,  301,  902,  306,    0,  700,  698,
      698,  243,  344,  699,  712,  696,  701,  707,  702,  333,
      696,  690,  694,  704,  701,  686,  703,    0,    0,    0,

      689,  690,  696,  686,    0,  694,  679,  688,  682,    0,
      691,  688,  690,  673,  683,  685,    0,  675,  679,    0,
      682,  349,  902,  712,  673,  664,  663,  680,  375,  681,
      671,  667,  659,  659,  662,  661,  699,  696,  652,  654,
      665,  668,  653,  693,  647,  645,  645,    0,    0,    0,
      658,  659,    0,    0,    0,    0,    0,    0,  655,  655,
      647,  700,  361,  682,  644,  638,  640,  641,  637,  388,
      649,    0,    0,  634,  631,  643,  668,    0,  634,  636,
      640,  631,  636,  666,  631,  634,    0,  621,  618,  678,
      631,  629,    0,  677,  653,    0,  617,  612,  624,  616,

      392,  607,  621,  616,  624,  623,  610,  618,  620,  607,
        0,  639,  605,    0,    0,    0,  613,    0,    0,  650,
      658,  902,    0,    0,  597,    0,  611,  611,  595,  590,
      605,  569,  577,  557,    0,  556,  574,    0,  573,  567,
      563,  902,  572,  530,  514,  510,  503,  508,  350,  497,
        0,    0,  509,    0,  460,  478,  463,  413,  403,  396,
      409,  409,  393,  404,  407,  406,    0,  405,  387,  394,
      390,  389,  381,  399,    0,  432,  350,  395,    0,    0,
      436,  387,  385,  388,  379,    0,  902,  173,    0,  387,
      377,  902,  366,  372,  340,  383,  377,  372,  375,  351,

      361,  374,  364,  902,  365,  356,    0,  369,  376,  372,
      372,  239,  352,  370,  386,  360,  902,  393,  364,  388,
      366,  399,  363,  397,  396,  343,  394,  282,  252,  216,
      211,  134,  102,  122,   98,  902,  902,  460,  473,  486,
      495,  508,  517,  528,  541,  550,  563,  572,  580,  593,
      603,  615,  628,  641
    } ;

static const flex_int16_t yy_def[555] =
    {   0,
      537,    1,  537,  537,  537,  538,  537,  539,  537,  537,
      537,  540,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  541,  541,
      537,  537,  537,  537,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      537,  537,  537,  537,  537,  538,  537,  539,  537,  539,
      537,  537,  537,  537,  537,  537,  537,  540,  537,  540,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  542,
      537,   78,   21,   22,  537,  537,  537,  543,  537,  537,
      537,  537,  537,  537,  537,  537,  541,  544,  545,  537,

      537,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  537,  537,  537,  537,  537,  537,  537,  537,
      542,  537,  537,  537,  546,  537,  537,  537,  543,  537,
      537,  544,  537,  544,  545,  537,  545,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,

      541,  541,  541,  541,  541,  541,  547,  537,  537,  537,
      548,  537,  537,  537,  537,  537,  537,  537,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  547,
      537,  537,  537,  537,  537,  537,  537,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,

      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      537,  537,  537,  541,  541,  541,  541,  541,  537,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  537,  537,  541,  541,  541,  541,  541,  537,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  549,  550,  541,  541,  541,  541,  541,  537,

      537,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  537,  541,  541,  551,
      550,  537,  541,  541,  541,  541,  537,  537,  537,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      537,  537,  551,  541,  537,  537,  537,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  537,  541,  537,  537,
      537,  541,  537,  552,  541,  541,  541,  541,  537,  541,
      537,  537,  537,  541,  552,  552,  552,  541,  541,  541,
      537,  541,  537,  537,  537,  541,  537,  552,  541,  537,
      541,  537,  537,  537,  552,  537,  541,  537,  537,  552,

      537,  541,  537,  537,  552,  537,  541,  537,  552,  537,
      537,  552,  537,  537,  552,  537,  537,  552,  537,  552,
      537,  553,  537,  553,  553,  537,  553,  537,  537,  537,
      537,  537,  537,  554,  554,  537,    0,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537
    } ;

static const flex_int16_t yy_nxt[979] =
    {   0,
        4,    5,    6,    5,    5,    7,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   22,   22,   22,   22,   22,   22,   23,   24,   25,
       26,   27,   28,   29,   29,   29,   29,   29,   30,   29,
       29,   29,   31,   32,   33,   34,   35,   36,   37,   38,
       39,   40,   41,   42,   29,   43,   29,   29,   44,   29,
       29,   29,   29,   45,   46,   47,   48,   49,   50,   29,
       29,   29,   51,   52,   53,   54,   55,   59,   55,   55,
       61,   64,   65,   66,   69,   72,  133,   77,   74,   78,
       78,   78,   78,   78,   78,   78,   78,   90,   95,   96,

      536,   73,   75,   76,   67,   79,  106,   98,  107,  118,
       80,   99,  119,  108,   60,  109,   91,   70,   92,   93,
      113,  115,   81,  116,  536,  121,   62,   59,  153,  134,
      114,  160,  117,  122,   63,   82,  161,   83,   83,   83,
       83,   83,   83,   84,   84,  102,   69,  103,  110,   55,
      104,   55,   55,   85,  196,  111,   86,  105,   87,   88,
      125,  126,  112,  148,   60,  154,  189,  534,  202,   85,
      192,  127,  197,  190,  128,  204,   86,  203,  205,   70,
      533,  193,  194,  148,   87,  487,  147,   88,   82,  153,
       84,   84,   84,   84,   84,   84,   84,   84,  135,  135,

      135,  135,  135,  135,  135,  135,   85,  198,  144,   86,
      144,   87,  147,  145,  145,  145,  145,  145,  145,  145,
      145,  221,   85,  199,  222,  156,  154,  214,  142,   86,
      143,  537,  146,  216,  147,  495,  156,   87,   78,   78,
       78,   78,   78,   78,   78,   78,  207,  214,  142,  224,
      225,  487,  146,  216,  139,  140,  143,  140,  157,  537,
      147,  135,  135,  135,  135,  135,  135,  135,  135,  157,
      139,  140,  226,  212,  233,  213,  532,  140,  162,  531,
      163,  164,  165,  227,  234,  289,  166,  244,  245,  327,
      328,  167,  290,  212,  168,  169,  170,  171,  172,  173,

      210,  213,  210,  530,  515,  211,  211,  211,  211,  211,
      211,  211,  211,  145,  145,  145,  145,  145,  145,  145,
      145,  215,  217,  215,  218,  211,  211,  211,  211,  211,
      211,  211,  211,  140,  213,  140,  274,  215,  275,  277,
      276,  276,  217,  215,  323,  329,  529,  329,  329,  140,
      218,  463,  487,  337,  463,  140,  274,  338,  275,  277,
      213,  464,  487,  487,  323,  394,  276,  276,  363,  363,
      363,  363,  363,  363,  363,  363,  329,  487,  329,  329,
      363,  363,  363,  363,  363,  363,  363,  363,  487,  401,
      330,  401,  401,  401,  463,  401,  401,  463,  487,  522,

      487,  488,  505,  500,  475,  487,  527,  528,  527,  525,
      526,  525,  523,  521,  509,  519,  517,  516,  514,  513,
      511,  510,  508,  512,  507,  506,  504,  503,  502,  501,
      499,  498,  497,  496,  494,  493,  492,  518,  428,  491,
      490,  489,  369,  520,  487,  486,  485,  484,  483,  482,
      481,  480,  479,  478,  477,  474,  473,  472,  471,  429,
       56,   56,  470,   56,   56,   56,   56,   56,   56,   56,
       56,   56,   56,   58,   58,   58,   58,   58,   58,   58,
       58,   58,   58,   58,   58,   58,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   68,   68,   68,   68,   97,

       97,   97,   97,   97,   97,   97,   97,   97,  141,  141,
      469,  141,  141,  141,  141,  141,  141,  141,  141,  141,
      141,  149,  149,  149,  468,  467,  149,  149,  152,  152,
      152,  152,  152,  152,  152,  152,  152,  152,  152,  152,
      152,  155,  155,  155,  155,  155,  155,  155,  155,  155,
      155,  155,  155,  155,  145,  466,  145,  465,  145,  462,
      145,  461,  145,  270,  270,  270,  270,  270,  270,  270,
      270,  270,  270,  270,  270,  270,  211,  460,  211,  459,
      211,  458,  211,  442,  211,  420,  420,  420,  420,  420,
      420,  420,  420,  421,  421,  421,  421,  421,  421,  421,

      421,  421,  421,  421,  421,  421,  443,  443,  443,  443,
      443,  443,  443,  443,  443,  443,  476,  457,  456,  455,
      454,  453,  452,  451,  476,  476,  476,  476,  524,  524,
      450,  524,  524,  524,  524,  524,  524,  524,  524,  524,
      524,  535,  535,  535,  535,  535,  535,  535,  535,  535,
      535,  535,  535,  535,  449,  448,  447,  446,  445,  444,
      422,  442,  441,  440,  439,  438,  437,  436,  435,  434,
      433,  432,  431,  430,  427,  426,  425,  424,  423,  422,
      419,  418,  417,  416,  415,  414,  413,  412,  411,  410,
      409,  408,  407,  406,  405,  404,  403,  402,  400,  399,

      398,  397,  396,  395,  393,  392,  391,  390,  389,  388,
      387,  386,  385,  384,  383,  382,  381,  380,  379,  378,
      377,  376,  375,  374,  373,  372,  371,  370,  368,  367,
      366,  365,  364,  362,  361,  360,  359,  358,  357,  356,
      355,  354,  353,  352,  351,  350,  349,  348,  347,  346,
      345,  344,  343,  342,  341,  340,  339,  336,  335,  334,
      333,  332,  331,  326,  325,  324,  322,  321,  271,  320,
      319,  318,  317,  316,  315,  314,  313,  312,  311,  310,
      309,  308,  307,  306,  305,  304,  303,  302,  301,  300,
      299,  298,  297,  296,  295,  294,  293,  292,  291,  288,

      287,  286,  285,  284,  283,  282,  281,  280,  279,  278,
      273,  272,  271,  269,  268,  267,  266,  265,  264,  263,
      262,  261,  260,  259,  258,  257,  256,  255,  254,  253,
      252,  251,  250,  249,  248,  247,  246,  243,  242,  241,
      240,  239,  238,  237,  236,  235,  232,  231,  230,  229,
      228,  223,  220,  219,  537,  537,  209,  208,  206,  201,
      200,  195,  191,  188,  187,  186,  185,  184,  183,  182,
      181,  180,  179,  178,  177,  176,  175,  174,  159,  158,
      151,  150,  138,  537,  137,  136,  537,  132,  131,  130,
      129,  124,  123,  120,  101,  100,   94,   89,   71,   57,

      537,    3,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537
    } ;

static const flex_int16_t yy_chk[979] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    5,    8,    5,    5,
        9,   10,   10,   11,   12,   16,   52,   19,   18,   19,
       19,   19,   19,   19,   19,   19,   19,   25,   27,   27,

      535,   16,   18,   18,   11,   20,   36,   30,   36,   41,
       20,   30,   41,   37,    8,   37,   25,   12,   25,   25,
       39,   40,   20,   40,  534,   43,    9,   58,   98,   52,
       39,  104,   40,   43,    9,   21,  104,   21,   21,   21,
       21,   21,   21,   21,   21,   35,   68,   35,   38,   55,
       35,   55,   55,   21,  126,   38,   21,   35,   21,   21,
       46,   46,   38,   87,   58,   98,  122,  533,  130,   21,
      124,   46,  126,  122,   46,  131,   21,  130,  131,   68,
      532,  124,  124,   87,   21,  488,  146,   21,   22,  152,
       22,   22,   22,   22,   22,   22,   22,   22,   61,   61,

       61,   61,   61,   61,   61,   61,   22,  127,   85,   22,
       85,   22,  146,   85,   85,   85,   85,   85,   85,   85,
       85,  160,   22,  127,  160,   99,  152,  143,   83,   22,
       83,   83,   86,  148,   86,  488,  155,   22,   78,   78,
       78,   78,   78,   78,   78,   78,  135,  143,   83,  162,
      162,  512,   86,  148,   78,   78,   83,   78,   99,   83,
       86,  135,  135,  135,  135,  135,  135,  135,  135,  155,
       78,   78,  163,  142,  169,  142,  531,   78,  105,  530,
      105,  105,  105,  163,  169,  230,  105,  180,  180,  282,
      282,  105,  230,  142,  105,  105,  105,  105,  105,  105,

      139,  142,  139,  529,  512,  139,  139,  139,  139,  139,
      139,  139,  139,  144,  144,  144,  144,  144,  144,  144,
      144,  145,  149,  145,  149,  210,  210,  210,  210,  210,
      210,  210,  210,  211,  212,  211,  214,  145,  217,  218,
      217,  275,  149,  145,  277,  283,  528,  283,  283,  211,
      149,  449,  495,  290,  449,  211,  214,  290,  217,  218,
      212,  449,  477,  500,  277,  363,  217,  275,  322,  322,
      322,  322,  322,  322,  322,  322,  329,  505,  329,  329,
      363,  363,  363,  363,  363,  363,  363,  363,  509,  370,
      283,  370,  370,  401,  463,  401,  401,  463,  515,  520,

      520,  477,  500,  495,  463,  518,  527,  526,  525,  524,
      523,  522,  521,  519,  505,  516,  514,  513,  511,  510,
      508,  506,  503,  509,  502,  501,  499,  498,  497,  496,
      494,  493,  491,  490,  485,  484,  483,  515,  401,  482,
      481,  478,  329,  518,  476,  474,  473,  472,  471,  470,
      469,  468,  466,  465,  464,  462,  461,  460,  459,  401,
      538,  538,  458,  538,  538,  538,  538,  538,  538,  538,
      538,  538,  538,  539,  539,  539,  539,  539,  539,  539,
      539,  539,  539,  539,  539,  539,  540,  540,  540,  540,
      540,  540,  540,  540,  540,  540,  540,  540,  540,  541,

      541,  541,  541,  541,  541,  541,  541,  541,  542,  542,
      457,  542,  542,  542,  542,  542,  542,  542,  542,  542,
      542,  543,  543,  543,  456,  455,  543,  543,  544,  544,
      544,  544,  544,  544,  544,  544,  544,  544,  544,  544,
      544,  545,  545,  545,  545,  545,  545,  545,  545,  545,
      545,  545,  545,  545,  546,  453,  546,  450,  546,  448,
      546,  447,  546,  547,  547,  547,  547,  547,  547,  547,
      547,  547,  547,  547,  547,  547,  548,  446,  548,  445,
      548,  444,  548,  443,  548,  549,  549,  549,  549,  549,
      549,  549,  549,  550,  550,  550,  550,  550,  550,  550,

      550,  550,  550,  550,  550,  550,  551,  551,  551,  551,
      551,  551,  551,  551,  551,  551,  552,  441,  440,  439,
      437,  436,  434,  433,  552,  552,  552,  552,  553,  553,
      432,  553,  553,  553,  553,  553,  553,  553,  553,  553,
      553,  554,  554,  554,  554,  554,  554,  554,  554,  554,
      554,  554,  554,  554,  431,  430,  429,  428,  427,  425,
      421,  420,  417,  413,  412,  410,  409,  408,  407,  406,
      405,  404,  403,  402,  400,  399,  398,  397,  395,  394,
      392,  391,  390,  389,  388,  386,  385,  384,  383,  382,
      381,  380,  379,  377,  376,  375,  374,  371,  369,  368,

      367,  366,  365,  364,  362,  361,  360,  359,  352,  351,
      347,  346,  345,  344,  343,  342,  341,  340,  339,  338,
      337,  336,  335,  334,  333,  332,  331,  330,  328,  327,
      326,  325,  324,  321,  319,  318,  316,  315,  314,  313,
      312,  311,  309,  308,  307,  306,  304,  303,  302,  301,
      297,  296,  295,  294,  293,  292,  291,  289,  288,  287,
      286,  285,  284,  281,  280,  279,  273,  272,  270,  269,
      268,  266,  265,  264,  263,  262,  261,  260,  259,  258,
      257,  256,  255,  253,  251,  250,  247,  246,  245,  244,
      241,  238,  237,  236,  235,  234,  233,  232,  231,  229,

      228,  227,  226,  225,  224,  223,  222,  221,  220,  219,
      209,  208,  207,  206,  205,  204,  203,  202,  201,  200,
      199,  198,  197,  196,  195,  194,  193,  192,  191,  189,
      188,  186,  185,  184,  183,  182,  181,  179,  178,  177,
      176,  175,  173,  172,  171,  170,  168,  167,  166,  165,
      164,  161,  159,  158,  157,  154,  137,  136,  132,  129,
      128,  125,  123,  120,  119,  118,  117,  116,  115,  114,
      113,  112,  111,  110,  109,  108,  107,  106,  103,  102,
       96,   92,   77,   70,   63,   62,   60,   50,   49,   48,
       47,   45,   44,   42,   34,   32,   26,   23,   15,    7,

        3,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537,  537,  537,
      537,  537,  537,  537,  537,  537,  537,  537
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "scannerlexer.l"
/* -*- Mode: C -*-
 * GObject introspection: C lexer
 *
 * Copyright (c) 1997 Sandro Sigala  <ssigala@globalnet.it>
 * Copyright (c) 2007-2008 Jürg Billeter  <j@bitron.ch>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#line 31 "scannerlexer.l"
#include <ctype.h>
#include <stdio.h>
#include <stdlib.h>

#include "scanner.h"
#include "scannerparser.h"
#include "grealpath.h"

int lineno;
char linebuf[2000];

#undef YY_BUF_SIZE
#define YY_BUF_SIZE 1048576

extern int yylex (GIGenerator *igenerator);
#define YY_DECL int yylex (GIGenerator *igenerator)
#define yywrap() (1)
#define YY_SKIP_YYWRAP
static void parse_comment (GIGenerator *igenerator);
static void process_linemarks (GIGenerator *igenerator, gboolean has_line);
static int check_identifier (GIGenerator *igenerator, const char *);
static int parse_ignored_macro (void);
static void print_error (GIGenerator *igenerator);
#line 1006 "scannerlexer.c"
#line 1007 "scannerlexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 65 "scannerlexer.l"


#line 1231 "scannerlexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 538 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 902 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];

find_rule: /* we branch to this label when backing up */

		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 67 "scannerlexer.l"
{ strncpy(linebuf, yytext+1, sizeof(linebuf)); /* save the next line */
						linebuf[sizeof(linebuf)-1]='\0';
						/* printf("%4d:%s\n",lineno,linebuf); */
						yyless(1);      /* give back all but the \n to rescan */
						++lineno;
					}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 73 "scannerlexer.l"
{ ++lineno; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 75 "scannerlexer.l"
{ /* Ignore whitespace. */ }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 77 "scannerlexer.l"
{ parse_comment(igenerator); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 78 "scannerlexer.l"
{ /* Ignore C++ style comments. */ }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 80 "scannerlexer.l"
{ yyless (yyleng - 1); return FUNCTION_MACRO; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 81 "scannerlexer.l"
{ return OBJECT_MACRO; }
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 83 "scannerlexer.l"
{ process_linemarks(igenerator, FALSE); }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 84 "scannerlexer.l"
{ process_linemarks(igenerator, TRUE); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 85 "scannerlexer.l"
{ }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 86 "scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 87 "scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 88 "scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 89 "scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 90 "scannerlexer.l"
{ return '['; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 91 "scannerlexer.l"
{ return '['; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 92 "scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 93 "scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 94 "scannerlexer.l"
{ return '('; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 95 "scannerlexer.l"
{ return ')'; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 96 "scannerlexer.l"
{ return ';'; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 97 "scannerlexer.l"
{ return ':'; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 98 "scannerlexer.l"
{ return ELLIPSIS; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 99 "scannerlexer.l"
{ return '?'; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 100 "scannerlexer.l"
{ return '.'; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 101 "scannerlexer.l"
{ return '+'; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 102 "scannerlexer.l"
{ return '-'; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 103 "scannerlexer.l"
{ return '*'; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 104 "scannerlexer.l"
{ return '/'; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 105 "scannerlexer.l"
{ return '%'; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 106 "scannerlexer.l"
{ return '^'; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 107 "scannerlexer.l"
{ return '&'; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 108 "scannerlexer.l"
{ return '|'; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 109 "scannerlexer.l"
{ return '~'; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 110 "scannerlexer.l"
{ return '!'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 111 "scannerlexer.l"
{ return '='; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 112 "scannerlexer.l"
{ return '<'; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 113 "scannerlexer.l"
{ return '>'; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 114 "scannerlexer.l"
{ return ADDEQ; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 115 "scannerlexer.l"
{ return SUBEQ; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 116 "scannerlexer.l"
{ return MULEQ; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 117 "scannerlexer.l"
{ return DIVEQ; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 118 "scannerlexer.l"
{ return MODEQ; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 119 "scannerlexer.l"
{ return XOREQ; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 120 "scannerlexer.l"
{ return ANDEQ; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 121 "scannerlexer.l"
{ return OREQ; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 122 "scannerlexer.l"
{ return SL; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 123 "scannerlexer.l"
{ return SR; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 124 "scannerlexer.l"
{ return SLEQ; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 125 "scannerlexer.l"
{ return SREQ; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 126 "scannerlexer.l"
{ return EQ; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 127 "scannerlexer.l"
{ return NOTEQ; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 128 "scannerlexer.l"
{ return LTEQ; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 129 "scannerlexer.l"
{ return GTEQ; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 130 "scannerlexer.l"
{ return ANDAND; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 131 "scannerlexer.l"
{ return OROR; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 132 "scannerlexer.l"
{ return PLUSPLUS; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 133 "scannerlexer.l"
{ return MINUSMINUS; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 134 "scannerlexer.l"
{ return ','; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 135 "scannerlexer.l"
{ return ARROW; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 137 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 138 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 139 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 140 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 141 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 142 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 143 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 144 "scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 145 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 146 "scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 147 "scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 148 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 149 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 150 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 151 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 152 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 153 "scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 154 "scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 155 "scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 156 "scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 157 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 158 "scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 159 "scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 160 "scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 85:
/* rule 85 can match eol */
YY_RULE_SETUP
#line 161 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 162 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 163 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 164 "scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 165 "scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 166 "scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 167 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 168 "scannerlexer.l"
{ return FLOAT; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 171 "scannerlexer.l"
{ if (igenerator->macro_scan) return check_identifier(igenerator, yytext); else REJECT; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 173 "scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 175 "scannerlexer.l"
{ return AUTO; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 176 "scannerlexer.l"
{ return BOOL; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 177 "scannerlexer.l"
{ return BREAK; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 178 "scannerlexer.l"
{ return CASE; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 179 "scannerlexer.l"
{ return CHAR; }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 180 "scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 181 "scannerlexer.l"
{ return CONTINUE; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 182 "scannerlexer.l"
{ return DEFAULT; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 183 "scannerlexer.l"
{ return DO; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 184 "scannerlexer.l"
{ return DOUBLE; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 185 "scannerlexer.l"
{ return ELSE; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 186 "scannerlexer.l"
{ return ENUM; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 187 "scannerlexer.l"
{ return EXTERN; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 188 "scannerlexer.l"
{ return FLOAT; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 189 "scannerlexer.l"
{ return FOR; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 190 "scannerlexer.l"
{ return GOTO; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 191 "scannerlexer.l"
{ return IF; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 192 "scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 193 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 194 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 195 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 196 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 197 "scannerlexer.l"
{ return INT; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 198 "scannerlexer.l"
{ return LONG; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 199 "scannerlexer.l"
{ return REGISTER; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 200 "scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 201 "scannerlexer.l"
{ return RETURN; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 202 "scannerlexer.l"
{ return SHORT; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 203 "scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 204 "scannerlexer.l"
{ return SIZEOF; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 205 "scannerlexer.l"
{ return STATIC; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 206 "scannerlexer.l"
{ return STRUCT; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 207 "scannerlexer.l"
{ return SWITCH; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 208 "scannerlexer.l"
{ return TYPEDEF; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 209 "scannerlexer.l"
{ return UNION; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 210 "scannerlexer.l"
{ return UNSIGNED; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 211 "scannerlexer.l"
{ return VOID; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 212 "scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 213 "scannerlexer.l"
{ return WHILE; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 215 "scannerlexer.l"
{ return check_identifier(igenerator, yytext); }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 217 "scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 218 "scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 219 "scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 221 "scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 222 "scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 140:
/* rule 140 can match eol */
YY_RULE_SETUP
#line 224 "scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 141:
/* rule 141 can match eol */
YY_RULE_SETUP
#line 225 "scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 142:
/* rule 142 can match eol */
YY_RULE_SETUP
#line 227 "scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 143:
/* rule 143 can match eol */
YY_RULE_SETUP
#line 228 "scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 230 "scannerlexer.l"
{ print_error(igenerator); }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 232 "scannerlexer.l"
ECHO;
	YY_BREAK
#line 2032 "scannerlexer.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 538 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    
	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 538 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 537);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 232 "scannerlexer.l"


static void parse_gtkdoc (GIGenerator *igenerator, int *c1, int *c2)
{
  gboolean isline = FALSE;
  gchar line[256];
  int i;
  gchar **parts;
  CDirective *directive;
  char *name, *value;

  i = 0;
  do {
      *c1 = *c2;
      if (*c1 == '\n')
	{
	  isline = TRUE;
	  break;
	}
      if (i >= 256)
	break;
      line[i++] = *c1;
      *c2 = input();

  } while (*c2 != EOF && !(*c1 == '*' && *c2 == '/'));
  
  if (!isline)
    return;

  line[i] = '\0';

  parts = g_strsplit (line, ": ", 2);

  if (g_strv_length (parts) == 2)
    {
      name = parts[0];
      value = parts[1];
    }
  else /* parts == 1 */
    {
      name = parts[0];
      value = NULL;
    }
  
  directive = cdirective_new (name, value);
  igenerator->directives = g_slist_prepend (igenerator->directives,
					    directive);

  g_strfreev (parts);
}

static void parse_comment (GIGenerator *igenerator)
{
  int c1, c2;
  
  c1 = input();
  c2 = input();

  while (c2 != EOF && !(c1 == '*' && c2 == '/'))
    {
      if (c1 == '\n')
	++lineno;
      c1 = c2;
      c2 = input();

      if (c1 == ' ' && c2 == '@')
	{
	  c1 = c2;
	  c2 = input();
	  parse_gtkdoc (igenerator, &c1, &c2);
	}
    }
}

static int
check_identifier (GIGenerator *igenerator,
		  const char *s)
{
	/*
	 * This function checks if `s' is a type name or an
	 * identifier.
	 */

	if (g_igenerator_is_typedef (igenerator, s)) {
		return TYPEDEF_NAME;
	} else if (strcmp (s, "__builtin_va_list") == 0) {
		return TYPEDEF_NAME;
	}

	return IDENTIFIER;
}

/*
 * # linenum "filename" flags
 *  See http://gcc.gnu.org/onlinedocs/cpp/Preprocessor-Output.html
 **/

static void
process_linemarks (GIGenerator *igenerator, gboolean has_line)
{
	char escaped_filename[1025];
	char *filename;
	char *real;

	if (has_line)
		sscanf(yytext, "#line %d \"%1024[^\"]\"", &lineno, escaped_filename);
	else
		sscanf(yytext, "# %d \"%1024[^\"]\"", &lineno, escaped_filename);

	filename = g_strcompress (escaped_filename);

        real = g_realpath (filename);
        if (real)
          {
            g_free (filename);
            filename = real;
          }

        if (igenerator->current_filename)
          g_free (igenerator->current_filename);
	igenerator->current_filename = filename;
}

/*
 * This parses a macro which is ignored, such as
 * __attribute__((x)) or __asm__ (x)
 */
static int
parse_ignored_macro (void)
{
	int c;
	int nest;

	while ((c = input ()) != EOF && isspace (c))
		;
	if (c != '(')
		return FALSE;

	nest = 0;
	while ((c = input ()) != EOF && (nest > 0 || c != ')')) {
		if (c == '(')
			nest++;
		else if (c == ')')
			nest--;
		else if (c == '"') {
			while ((c = input ()) != EOF && c != '"') {
				if (c == '\\')
					c = input ();
			}
		} else if (c == '\'') {
			c = input ();
			if (c == '\\')
				c = input ();
			else if (c == '\'')
				return FALSE;
			c = input ();
			if (c != '\'')
				return FALSE;
		} else if (c == '\n')
			lineno++;
	}

	return TRUE;
}

static void
print_error (GIGenerator *igenerator)
{
  if (yytext[0]) {
    fprintf(stderr, "%s:%d: unexpected character `%c'\n", igenerator->current_filename, lineno, yytext[0]);
  }
}

